@@ -134,18 +134,22 @@ def multiple_clusters_config() -> Dict[str, Cluster]:
             name="default",
             registry_url=URL("https://registry-dev.neu.ro"),
             storage_url=URL("https://storage-dev.neu.ro"),
+            blob_storage_url=URL("https://blob-storage-dev.neu.ro"),
             users_url=URL("https://users-dev.neu.ro"),
             monitoring_url=URL("https://jobs-dev.neu.ro"),
             secrets_url=URL("https://secrets-dev.neu.ro"),
+            disks_url=URL("https://disks-dev.neu.ro"),
             presets={"cpu-small": Preset(cpu=1, memory_mb=2 * 1024)},
         ),
         "another": Cluster(
             name="another",
             registry_url=URL("https://registry2-dev.neu.ro"),
             storage_url=URL("https://storage2-dev.neu.ro"),
+            blob_storage_url=URL("https://blob-storage-dev.neu.ro"),
             users_url=URL("https://users2-dev.neu.ro"),
             monitoring_url=URL("https://jobs2-dev.neu.ro"),
             secrets_url=URL("https://secrets2-dev.neu.ro"),
+            disks_url=URL("https://disks-dev.neu.ro"),
             presets={"cpu-large": Preset(cpu=7, memory_mb=14 * 1024)},
         ),
     }
@@ -167,6 +171,7 @@ async def test_get_cluster_name_from_local(
         assert client.config.cluster_name == "default"
         assert client.config.registry_url == URL("https://registry-dev.neu.ro")
         assert client.config.storage_url == URL("https://storage-dev.neu.ro")
+        assert client.config.blob_storage_url == URL("https://blob-storage-dev.neu.ro")
         assert client.config.monitoring_url == URL("https://jobs-dev.neu.ro")
         assert client.config.secrets_url == URL("https://secrets-dev.neu.ro")
         assert client.config.presets == {"cpu-small": Preset(cpu=1, memory_mb=2 * 1024)}
@@ -233,7 +238,7 @@ async def test_presets(
             "cpu-large": Preset(
                 cpu=7,
                 memory_mb=14336,
-                is_preemptible=False,
+                scheduler_enabled=False,
                 gpu=None,
                 gpu_model=None,
                 tpu_type=None,
@@ -242,7 +247,7 @@ async def test_presets(
             "cpu-small": Preset(
                 cpu=7,
                 memory_mb=2048,
-                is_preemptible=False,
+                scheduler_enabled=False,
                 gpu=None,
                 gpu_model=None,
                 tpu_type=None,
@@ -251,7 +256,7 @@ async def test_presets(
             "gpu-large": Preset(
                 cpu=7,
                 memory_mb=61440,
-                is_preemptible=False,
+                scheduler_enabled=False,
                 gpu=1,
                 gpu_model="nvidia-tesla-v100",
                 tpu_type=None,
@@ -260,7 +265,7 @@ async def test_presets(
             "gpu-small": Preset(
                 cpu=7,
                 memory_mb=30720,
-                is_preemptible=False,
+                scheduler_enabled=False,
                 gpu=1,
                 gpu_model="nvidia-tesla-k80",
                 tpu_type=None,
@@ -291,9 +296,11 @@ async def test_clusters(
                 name="default",
                 registry_url=URL("https://registry-dev.neu.ro"),
                 storage_url=srv.make_url("/storage"),
+                blob_storage_url=srv.make_url("/blob"),
                 users_url=srv.make_url("/"),
                 monitoring_url=srv.make_url("/jobs"),
                 secrets_url=srv.make_url("/secrets"),
+                disks_url=srv.make_url("/disk"),
                 presets=mock.ANY,
             )
         }
@@ -304,9 +311,11 @@ async def test_fetch(
 ) -> None:
     registry_url = "https://registry2-dev.neu.ro"
     storage_url = "https://storage2-dev.neu.ro"
+    blob_storage_url = "https://blob-storage2-dev.neu.ro"
     users_url = "https://users2-dev.neu.ro"
     monitoring_url = "https://jobs2-dev.neu.ro"
     secrets_url = "https://secrets2-dev.neu.ro"
+    disks_url = "https://disks2-dev.neu.ro"
     auth_url = "https://dev-neuro.auth0.com/authorize"
     token_url = "https://dev-neuro.auth0.com/oauth/token"
     logout_url = "https://dev-neuro.auth0.com/v2/logout"
@@ -327,9 +336,11 @@ async def test_fetch(
                 "name": "default",
                 "registry_url": registry_url,
                 "storage_url": storage_url,
+                "blob_storage_url": blob_storage_url,
                 "users_url": users_url,
                 "monitoring_url": monitoring_url,
                 "secrets_url": secrets_url,
+                "disks_url": disks_url,
                 "resource_presets": [
                     {"name": "cpu-small", "cpu": 2, "memory_mb": 2 * 1024}
                 ],
@@ -349,16 +360,18 @@ async def test_fetch(
         assert client.config.clusters == {
             "default": Cluster(
                 name="default",
-                registry_url=URL("https://registry2-dev.neu.ro"),
-                storage_url=URL("https://storage2-dev.neu.ro"),
-                users_url=URL("https://users2-dev.neu.ro"),
-                monitoring_url=URL("https://jobs2-dev.neu.ro"),
-                secrets_url=URL("https://secrets2-dev.neu.ro"),
+                registry_url=URL(registry_url),
+                storage_url=URL(storage_url),
+                blob_storage_url=URL(blob_storage_url),
+                users_url=URL(users_url),
+                monitoring_url=URL(monitoring_url),
+                secrets_url=URL(secrets_url),
+                disks_url=URL(disks_url),
                 presets={
                     "cpu-small": Preset(
                         cpu=2,
                         memory_mb=2048,
-                        is_preemptible=False,
+                        scheduler_enabled=False,
                         gpu=None,
                         gpu_model=None,
                         tpu_type=None,
@@ -375,9 +388,11 @@ async def test_fetch_dropped_selected_cluster(
     # the test returns the same as for valid answer but the cluster name is different
     registry_url = "https://registry2-dev.neu.ro"
     storage_url = "https://storage2-dev.neu.ro"
+    blob_storage_url = "https://blob-storage2-dev.neu.ro"
     users_url = "https://users2-dev.neu.ro"
     monitoring_url = "https://jobs2-dev.neu.ro"
     secrets_url = "https://secrets2-dev.neu.ro"
+    disks_url = "https://disks2-dev.neu.ro"
     auth_url = "https://dev-neuro.auth0.com/authorize"
     token_url = "https://dev-neuro.auth0.com/oauth/token"
     logout_url = "https://dev-neuro.auth0.com/v2/logout"
@@ -398,9 +413,11 @@ async def test_fetch_dropped_selected_cluster(
                 "name": "another",
                 "registry_url": registry_url,
                 "storage_url": storage_url,
+                "blob_storage_url": blob_storage_url,
                 "users_url": users_url,
                 "monitoring_url": monitoring_url,
                 "secrets_url": secrets_url,
+                "disks_url": disks_url,
                 "resource_presets": [
                     {"name": "cpu-small", "cpu": 2, "memory_mb": 2 * 1024}
                 ],
@@ -466,9 +483,11 @@ async def test_check_server_mismatch_clusters(
     # the test returns the same as for valid answer but the cluster name is different
     registry_url = "https://registry2-dev.neu.ro"
     storage_url = "https://storage2-dev.neu.ro"
+    blob_storage_url = "https://blob-storage2-dev.neu.ro"
     users_url = "https://users2-dev.neu.ro"
     monitoring_url = "https://jobs2-dev.neu.ro"
     secrets_url = "https://secrets2-dev.neu.ro"
+    disks_url = "https://disks2-dev.neu.ro"
     auth_url = "https://dev-neuro.auth0.com/authorize"
     token_url = "https://dev-neuro.auth0.com/oauth/token"
     logout_url = "https://dev-neuro.auth0.com/v2/logout"
@@ -489,9 +508,11 @@ async def test_check_server_mismatch_clusters(
                 "name": "another",
                 "registry_url": registry_url,
                 "storage_url": storage_url,
+                "blob_storage_url": blob_storage_url,
                 "users_url": users_url,
                 "monitoring_url": monitoring_url,
                 "secrets_url": secrets_url,
+                "disks_url": disks_url,
                 "resource_presets": [
                     {"name": "cpu-small", "cpu": 2, "memory_mb": 2 * 1024}
                 ],
@@ -521,9 +542,11 @@ async def test_check_server_mismatch_auth(
     # the test returns the same as for valid answer but the cluster name is different
     registry_url = "https://registry2-dev.neu.ro"
     storage_url = "https://storage2-dev.neu.ro"
+    blob_storage_url = "https://blob-storage2-dev.neu.ro"
     users_url = "https://users2-dev.neu.ro"
     monitoring_url = "https://jobs2-dev.neu.ro"
     secrets_url = "https://secrets2-dev.neu.ro"
+    disks_url = "https://disks2-dev.neu.ro"
     auth_url = "https://dev-neuro.auth0.com/authorize"
     token_url = "https://dev-neuro.auth0.com/oauth/token"
     logout_url = "https://dev-neuro.auth0.com/v2/logout"
@@ -543,9 +566,11 @@ async def test_check_server_mismatch_auth(
                 "name": "default",
                 "registry_url": registry_url,
                 "storage_url": storage_url,
+                "blob_storage_url": blob_storage_url,
                 "users_url": users_url,
                 "monitoring_url": monitoring_url,
                 "secrets_url": secrets_url,
+                "disks_url": disks_url,
                 "resource_presets": [
                     {"name": "cpu-small", "cpu": 2, "memory_mb": 2 * 1024}
                 ],
